﻿//########################################################################################################################################
// EPLAN_2DMountingPanelHelper
//########################################################################################################################################
// Function:    Easily change several user settings for faster 2D monting plate processes
//              (old script solution adopted to EPLAN V2022)
// 2023-01-02   (c) nairolf
//              Special THX to Johann Weiher for sharing the idea of creating PopUp menus in EPLAN 2023 ;)
//              He is a real unicorn :D
//########################################################################################################################################
// ChangeLog:
//----------------------------------------------------------------------------------------------------------------------------------------
//  2023-01-02   V1.0    nairolf
//                          - initial creation
//######################################################################################################################################## 

using Eplan.EplApi.ApplicationFramework;
using Eplan.EplApi.Base;
using Eplan.EplApi.Gui;
using Eplan.EplApi.Scripting;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Net;
using System.Security.Cryptography;
using System.Text;
using System.Windows.Forms;


namespace EPLAN_2DMountingPanelHelper
{
    public class EPLAN_2DMountingSettings
    {
        #region INTERNAL: DEFINE GLOBAL VARIABLES
        public static string globalString_ScriptSolutionName = "EPLAN_2DMountingPanelHelper.cs"; //Dateiname der eigenen Scriptlösung
        public static string globalString_ScriptVersionNo = "1.0.0";  //Versionsnummer der eigenen C#-Scriptapplikation
        public static string globalString_EPLANVersion = GetActiveEplanVersion();
        public static int globalInt_EPLANVersion = System.Convert.ToInt32(globalString_EPLANVersion.Replace(".", string.Empty));
        public static ISOCode.Language global_GuiLanguage = new Languages().GuiLanguage.GetNumber();

        public static MultiLangString global_mls_RibbOwnTabName = new MultiLangString();
        public static MultiLangString global_mls_CommandGroupName1 = new MultiLangString();

        #region provide SVG icon content       
        string _SVGIcon_MP_GripperFromMacro_Yes = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_GripperFromMacro_Yes.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"><rect x=\"63.625001\" y=\"-10\" width=\"43.5\" height=\"42.125\" id=\"rect22946\"/><rect x=\"50.875\" y=\"1.375\" width=\"31.625\" height=\"31\" id=\"rect22861\"/><rect x=\"12.993087\" y=\"12.374369\" width=\"40.039922\" height=\"40.65864\" id=\"rect22622\"/></defs><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"7.9999999\" inkscape:cx=\"35.3125\" inkscape:cy=\"26.25\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/><sodipodi:guide position=\"34,65.875\" orientation=\"1,0\" id=\"guide22626\" inkscape:locked=\"false\"/><sodipodi:guide position=\"48,30.125\" orientation=\"0,-1\" id=\"guide22628\" inkscape:locked=\"false\"/><sodipodi:guide position=\"83.125001,35.125\" orientation=\"0,-1\" id=\"guide23113\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><g id=\"g41350\" inkscape:label=\"Macro\" transform=\"matrix(1,0,0,0.90384712,-7.7121052,10.516138)\"><polygon points=\"24,16 24,26 28,26 28,12 18,12 18,16\" style=\"fill:#e2001a\" id=\"polygon40705\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"36,26 40,26 40,16 46,16 46,12 36,12\" style=\"fill:#e2001a\" id=\"polygon40707\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"36,38 36,52 46,52 46,48 40,48 40,38\" style=\"fill:#e2001a\" id=\"polygon40709\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"18,48 18,52 28,52 28,38 24,38 24,48\" style=\"fill:#e2001a\" id=\"polygon40711\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><path d=\"M13.741445 2.2790497V48.22037H59.682766V2.2790497zM56.811433 45.349037H16.612778V5.1503822h40.198655z\" style=\"fill:#bbbdbd;stroke-width:.717833;fill-opacity:1\" id=\"path40715\"/><path d=\"M28.098108 8.0217147H19.48411v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40717\"/><path d=\"M28.098108 33.863707H19.48411v8.613998h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40719\"/><path d=\"m45.326103 42.477705h8.613998v-8.613998h-8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40721\"/><path d=\"m53.940101 8.0217147h-8.613998v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40723\"/><path d=\"M28.098108 30.992375H45.326103V19.507045H28.098108zm2.871332-8.613998h11.48533v5.742665H30.96944z\" style=\"fill:#bbbdbd;stroke-width:.717833;fill-opacity:1\" id=\"path40725\"/></g><g aria-label=\"✓\" transform=\"matrix(1.9369675,0,0,1.5989277,-119.01228,36.752926)\" id=\"text22944\" style=\"font-size:26.6667px;text-align:center;text-anchor:middle;white-space:pre;shape-inside:url(#rect22946);display:inline;fill:#00c200;fill-opacity:1;stroke-width:7.01;stroke-linejoin:bevel;paint-order:fill markers stroke\"><path d=\"m76.416655 11.041693q0-.416667-.104166-.729167.0-.9375015 1.250001-1.6666691.833335-.4166672 1.250002-.4166672.520834.1041668.729167.6250008.625001 1.4583355.833335 1.9791695.208333.416667.416667.416667.208333.0.416667-.312501 3.541671-6.2500074 6.354175-9.6875118 2.187503-2.6041699 2.708337-3.0208371 1.666668-1.2500016 3.958338-1.3541684l.104167.520834q-1.770836 1.77083555-6.145841 7.9166766-4.270839 6.1458407-6.145842 9.6875127-.416667.937501-1.041668 1.145834-.3125.312501-1.354168.208334-.729167.104167-1.041668-.208334-.3125-.208333-.625001-.833334-1.041668-2.500003-1.562502-4.270839z\" style=\"fill:#00c200;fill-opacity:1\" id=\"path23083\"/></g><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m2.429903 27.704926c-1.21799.0-2.199511.980682-2.199511 2.198672v8.482476c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673v-8.482476c0-1.21799-.981521-2.198672-2.199511-2.198672zm1.829111 2.567312h5.616347c.737194.0 1.329695.592542 1.329695 1.329736v5.134625c0 .737195-.592501 1.331617-1.329695 1.331617H4.259014c-.737194.0-1.331776-.594422-1.331776-1.331617v-5.134625c0-.737194.594582-1.329736 1.331776-1.329736z\"/></g></svg>";
        string _SVGIcon_MP_GripperFromMacro_No = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_GripperFromMacro_No.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"><rect x=\"50.875\" y=\"1.375\" width=\"31.625\" height=\"31\" id=\"rect22861\"/><rect x=\"12.993087\" y=\"12.374369\" width=\"40.039922\" height=\"40.65864\" id=\"rect22622\"/></defs><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"7.9999999\" inkscape:cx=\"35.375\" inkscape:cy=\"36.25\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/><sodipodi:guide position=\"34,65.875\" orientation=\"1,0\" id=\"guide22626\" inkscape:locked=\"false\"/><sodipodi:guide position=\"48,30.125\" orientation=\"0,-1\" id=\"guide22628\" inkscape:locked=\"false\"/><sodipodi:guide position=\"61.125001,35.125\" orientation=\"0,-1\" id=\"guide23649\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><g id=\"g41350\" inkscape:label=\"Macro\" transform=\"matrix(1,0,0,0.90384712,-7.8371045,11.532965)\"><polygon points=\"24,26 28,26 28,12 18,12 18,16 24,16\" style=\"fill:#e2001a\" id=\"polygon40705\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"40,26 40,16 46,16 46,12 36,12 36,26\" style=\"fill:#e2001a\" id=\"polygon40707\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"36,52 46,52 46,48 40,48 40,38 36,38\" style=\"fill:#e2001a\" id=\"polygon40709\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"18,52 28,52 28,38 24,38 24,48 18,48\" style=\"fill:#e2001a\" id=\"polygon40711\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><path d=\"M13.741445 2.2790497V48.22037H59.682766V2.2790497zM56.811433 45.349037H16.612778V5.1503822h40.198655z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.717833\" id=\"path40715\"/><path d=\"M28.098108 8.0217147H19.48411v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40717\"/><path d=\"M28.098108 33.863707H19.48411v8.613998h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40719\"/><path d=\"m45.326103 42.477705h8.613998v-8.613998h-8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40721\"/><path d=\"m53.940101 8.0217147h-8.613998v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40723\"/><path d=\"M28.098108 30.992375H45.326103V19.507045H28.098108zm2.871332-8.613998h11.48533v5.742665H30.96944z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.717833\" id=\"path40725\"/></g><g aria-label=\"x\" transform=\"matrix(2.1978127,0,0,1.9864867,-97.263185,12.24695)\" id=\"text22859\" style=\"font-size:26.6667px;text-align:center;text-anchor:middle;white-space:pre;shape-inside:url(#rect22861);fill:#00f;stroke-width:7.01;stroke-linejoin:bevel;paint-order:fill markers stroke\"><path d=\"m65.287759 18.333511-4.934902-6.992197h2.669274l3.6849 5.390632 3.645838-5.390632h2.643233L68.0612 18.333511l5.20834 7.304696h-2.669275l-3.893234-5.703132-3.945317 5.703132h-2.643233z\" style=\"fill:red\" id=\"path22915\"/></g><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m2.429903 27.704926c-1.21799.0-2.199511.980682-2.199511 2.198672v8.482476c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673v-8.482476c0-1.21799-.981521-2.198672-2.199511-2.198672zm1.829111 2.567312h5.616347c.737194.0 1.329695.592542 1.329695 1.329736v5.134625c0 .737195-.592501 1.331617-1.329695 1.331617H4.259014c-.737194.0-1.331776-.594422-1.331776-1.331617v-5.134625c0-.737194.594582-1.329736 1.331776-1.329736z\"/></g></svg>";

        string _SVG_Icon_PlacementDirection_Horizontal = "<svg viewBox=\"0 0 64 64\" id=\"svg5215\" sodipodi:docname=\"MP_Horizontal.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs5219\"/><sodipodi:namedview id=\"namedview5217\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"6.5390625\" inkscape:cx=\"-1.9880526\" inkscape:cy=\"40.219833\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"svg5215\"/><g id=\"g6490\"><polygon points=\"4,0 0,0 0,4 0,40 4,40 4,4 40,4 40,0\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"polygon5198\" transform=\"scale(1.4434886)\"/><rect x=\"8\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5200\"/><rect x=\"8\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5202\"/><rect x=\"24\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5204\"/><rect x=\"24\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#0d9be2\" id=\"rect5206\"/><rect x=\"39.502987\" y=\"8.0764637\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6468\"/><rect x=\"8.2293911\" y=\"39.216248\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6472\"/><rect x=\"39.732376\" y=\"24.133812\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6474\"/></g><g id=\"g6660\" transform=\"matrix(1.2186688,0,0,1,-7.5893089,-2.1409797)\"><rect style=\"fill:red;stroke-width:8.01;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect6544\" width=\"37.620071\" height=\"4.7407427\" x=\"8.1313763\" y=\"54.110622\" rx=\".1875\" ry=\"1.3818361\"/><path id=\"rect6546\" style=\"fill:red;stroke-width:12.0145;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m45.371844 46.451833v19.546162l8.310263-9.176021c.104761-.115692-1.355091-2.118247-3.273166-4.491406l-1.492973-1.846607c-1.683815-2.083318-3.141592-3.737209-3.544124-4.032128z\"/></g></svg>";
        string _SVG_Icon_PlacementDirection_Vertical = "<svg viewBox=\"0 0 64 64\" id=\"svg5215\" sodipodi:docname=\"MP_Vertical.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs5219\"/><sodipodi:namedview id=\"namedview5217\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"9.2476308\" inkscape:cx=\"29.088532\" inkscape:cy=\"36.009223\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"svg5215\"/><g id=\"g6490\"><polygon points=\"4,0 0,0 0,4 0,40 4,40 4,4 40,4 40,0\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"polygon5198\" transform=\"scale(1.4434886)\"/><rect x=\"8\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5200\"/><rect x=\"8\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5202\"/><rect x=\"24\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5204\"/><rect x=\"24\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#0d9be2\" id=\"rect5206\"/><rect x=\"39.502987\" y=\"8.0764637\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6468\"/><rect x=\"8.2293911\" y=\"39.216248\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6472\"/><rect x=\"39.732376\" y=\"24.133812\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6474\"/></g><g id=\"g6660\" transform=\"matrix(0,1.2186688,-1,0,109.66125,-6.0766262)\"><rect style=\"fill:red;stroke-width:8.01;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect6544\" width=\"37.620071\" height=\"4.7407427\" x=\"8.1313763\" y=\"54.110622\" rx=\".1875\" ry=\"1.3818361\"/><path id=\"rect6546\" style=\"fill:red;stroke-width:12.0145;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m45.371844 46.451833v19.546162l8.310263-9.176021c.104761-.115692-1.355091-2.118247-3.273166-4.491406l-1.492973-1.846607c-1.683815-2.083318-3.141592-3.737209-3.544124-4.032128z\"/></g></svg>";

        string _SVGIcon_MP_LowerLeft = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_LowerLeft.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"11.313708\" inkscape:cx=\"57.364038\" inkscape:cy=\"56.745319\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m2.385709 50.395873c-1.21799.0-2.199511.980682-2.199511 2.198672v8.482476c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673v-8.482476c0-1.21799-.981521-2.198672-2.199511-2.198672zm1.829111 2.567312h5.616347c.737194.0 1.329695.592542 1.329695 1.329736v5.134625c0 .737195-.592501 1.331617-1.329695 1.331617H4.21482c-.737194.0-1.331776-.594422-1.331776-1.331617v-5.134625c0-.737194.594582-1.329736 1.331776-1.329736z\"/></g></svg>";
        string _SVGIcon_MP_LowerCenter = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_LowerCenter.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"5.656854\" inkscape:cx=\"43.487069\" inkscape:cy=\"42.249632\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/><sodipodi:guide position=\"34.117904,68.772971\" orientation=\"1,0\" id=\"guide819\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m28.385709 50.395873c-1.21799.0-2.199511.980682-2.199511 2.198672v8.482476c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673v-8.482476c0-1.21799-.981521-2.198672-2.199511-2.198672zm1.829111 2.567312h5.616347c.737194.0 1.329695.592542 1.329695 1.329736v5.134625c0 .737195-.592501 1.331617-1.329695 1.331617H30.21482c-.737194.0-1.331776-.594422-1.331776-1.331617v-5.134625c0-.737194.594582-1.329736 1.331776-1.329736z\"/></g></svg>";
        string _SVGIcon_MP_LowerRight = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_LowerRight.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"22.627417\" inkscape:cx=\"49.630057\" inkscape:cy=\"51.795572\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m52.385709 50.395873c-1.21799.0-2.199511.980682-2.199511 2.198672v8.482476c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673v-8.482476c0-1.21799-.981521-2.198672-2.199511-2.198672zm1.829111 2.567312h5.616347c.737194.0 1.329695.592542 1.329695 1.329736v5.134625c0 .737195-.592501 1.331617-1.329695 1.331617H54.21482c-.737194.0-1.331776-.594422-1.331776-1.331617v-5.134625c0-.737194.594582-1.329736 1.331776-1.329736z\"/></g></svg>";
        string _SVGIcon_MP_MiddleLeft = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_MiddleLeft.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"5.6568542\" inkscape:cx=\"31.996582\" inkscape:cy=\"15.202796\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m2.429903 27.704926c-1.21799.0-2.199511.980682-2.199511 2.198672v8.482476c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673v-8.482476c0-1.21799-.981521-2.198672-2.199511-2.198672zm1.829111 2.567312h5.616347c.737194.0 1.329695.592542 1.329695 1.329736v5.134625c0 .737195-.592501 1.331617-1.329695 1.331617H4.259014c-.737194.0-1.331776-.594422-1.331776-1.331617v-5.134625c0-.737194.594582-1.329736 1.331776-1.329736z\"/></g></svg>";
        string _SVGIcon_MP_MiddleCenter = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_Center.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"5.6568542\" inkscape:cx=\"31.996582\" inkscape:cy=\"15.379573\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/><sodipodi:guide position=\"34.117902,82.384776\" orientation=\"1,0\" id=\"guide2291\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-19.091883,31.649864\" orientation=\"0,-1\" id=\"guide2293\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m28.429903 27.704926c-1.21799.0-2.199511.980682-2.199511 2.198672v8.482476c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673v-8.482476c0-1.21799-.981521-2.198672-2.199511-2.198672zm1.829111 2.567312h5.616347c.737194.0 1.329695.592542 1.329695 1.329736v5.134625c0 .737195-.592501 1.331617-1.329695 1.331617h-5.616347c-.737194.0-1.331776-.594422-1.331776-1.331617v-5.134625c0-.737194.594582-1.329736 1.331776-1.329736z\"/></g></svg>";
        string _SVGIcon_MP_MiddleRight = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_MiddleRight.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"5.6568542\" inkscape:cx=\"31.996582\" inkscape:cy=\"15.202796\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m52.429903 27.704926c-1.21799.0-2.199511.980682-2.199511 2.198672v8.482476c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673v-8.482476c0-1.21799-.981521-2.198672-2.199511-2.198672zm1.829111 2.567312h5.616347c.737194.0 1.329695.592542 1.329695 1.329736v5.134625c0 .737195-.592501 1.331617-1.329695 1.331617h-5.616347c-.737194.0-1.331776-.594422-1.331776-1.331617v-5.134625c0-.737194.594582-1.329736 1.331776-1.329736z\"/></g></svg>";
        string _SVGIcon_MP_UpperLeft = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_UpperLeft.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"45.254834\" inkscape:cx=\"7.2920387\" inkscape:cy=\"7.3362329\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m2.7613603 6.012597c-1.2179899.0-2.19951078.9806829-2.19951078 2.1986728v8.4824762c0 1.21799.98152088 2.198673 2.19951078 2.198673h9.2787307c1.21799.0 2.199511-.980683 2.199511-2.198673V8.2112698c0-1.2179899-.981521-2.1986728-2.199511-2.1986728zM4.590471 8.5799096h5.616347c.737194.0 1.329695.5925421 1.329695 1.3297358v5.1346256c0 .737195-.592501 1.331617-1.329695 1.331617H4.590471c-.7371941.0-1.3317757-.594422-1.3317757-1.331617V9.9096454c0-.7371937.5945816-1.3297358 1.3317757-1.3297358z\"/></g></svg>";
        string _SVGIcon_MP_UpperCenter = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_UpperCenter.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"4\" inkscape:cx=\"22.75\" inkscape:cy=\"45\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m26.76136 6.012597c-1.21799.0-2.199511.9806829-2.199511 2.1986728v8.4824762c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673V8.2112698c0-1.2179899-.981521-2.1986728-2.199511-2.1986728zm1.829111 2.5673126h5.616347c.737194.0 1.329695.5925421 1.329695 1.3297358v5.1346256c0 .737195-.592501 1.331617-1.329695 1.331617h-5.616347c-.737194.0-1.331776-.594422-1.331776-1.331617V9.9096454c0-.7371937.594582-1.3297358 1.331776-1.3297358z\"/></g></svg>";
        string _SVGIcon_MP_UpperRight = "<svg viewBox=\"0 0 64 64\" id=\"svg22\" sodipodi:docname=\"MP_UpperRight.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs26\"/><sodipodi:namedview id=\"namedview24\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"22.627417\" inkscape:cx=\"65.628348\" inkscape:cy=\"13.656\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Verbindungen\" showguides=\"true\" inkscape:lockguides=\"false\"><sodipodi:guide position=\"-27.046834,53.923728\" orientation=\"0,-1\" id=\"guide1617\" inkscape:locked=\"false\"/><sodipodi:guide position=\"-25.544233,3.9843118\" orientation=\"0,-1\" id=\"guide1619\" inkscape:locked=\"false\"/><sodipodi:guide position=\"4.9497475,40.488699\" orientation=\"1,0\" id=\"guide1623\" inkscape:locked=\"false\"/><sodipodi:guide position=\"1.1875,64.875\" orientation=\"1,0\" id=\"guide1627\" inkscape:locked=\"false\"/><sodipodi:guide position=\"9.9878833,45.26167\" orientation=\"1,0\" id=\"guide4757\" inkscape:locked=\"false\"/><sodipodi:guide position=\"13.611806,48.973981\" orientation=\"0,-1\" id=\"guide4759\" inkscape:locked=\"false\"/><sodipodi:guide position=\"52.679455,8.9340593\" orientation=\"0,-1\" id=\"guide4761\" inkscape:locked=\"false\"/><sodipodi:guide position=\"55.065941,34.478292\" orientation=\"1,0\" id=\"guide4763\" inkscape:locked=\"false\"/><sodipodi:guide position=\"31.375,56.625\" orientation=\"0,-1\" id=\"guide4921\" inkscape:locked=\"false\"/><sodipodi:guide position=\"41.375,6.5\" orientation=\"0,-1\" id=\"guide4923\" inkscape:locked=\"false\"/><sodipodi:guide position=\"7.375,68.125\" orientation=\"1,0\" id=\"guide4925\" inkscape:locked=\"false\"/><sodipodi:guide position=\"57.25,71.625\" orientation=\"1,0\" id=\"guide4927\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"Verbindungen\" transform=\"matrix(1,0,0,1.1063818,0,-6.3845725)\"><path id=\"rect1679\" style=\"fill:#1022fa;fill-opacity:1;stroke-width:5.2;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m5.0820312 10.164062c-.073451.0-.1328124.05936-.1328124.132813v49.585937c0 .07345.059362.132813.1328124.132813H59.794922c.07345.0.132812-.05936.132812-.132813V10.296875c0-.07345-.05936-.132813-.132812-.132813zM10.121094 14.9375h44.810547c.122867.0.222656.09979.222656.222656v39.771485c0 .122867-.09979.222656-.222656.222656H10.121094c-.122868.0-.2207034-.09979-.2207034-.222656V15.160156c0-.122868.097835-.222656.2207034-.222656z\"/><path id=\"rect4822\" style=\"fill:red;fill-opacity:1;stroke-width:8.11337;stroke-linejoin:bevel;stroke-dasharray:none;paint-order:fill markers stroke\" d=\"m52.429903 6.012597c-1.21799.0-2.199511.9806829-2.199511 2.1986728v8.4824762c0 1.21799.981521 2.198673 2.199511 2.198673h9.278731c1.21799.0 2.199511-.980683 2.199511-2.198673V8.2112698c0-1.2179899-.981521-2.1986728-2.199511-2.1986728zm1.829111 2.5673126h5.616347c.737194.0 1.329695.5925421 1.329695 1.3297358v5.1346256c0 .737195-.592501 1.331617-1.329695 1.331617h-5.616347c-.737194.0-1.331776-.594422-1.331776-1.331617V9.9096454c0-.7371937.594582-1.3297358 1.331776-1.3297358z\"/></g></svg>";

        string _SVGIcon_PlacmentAngle_0 = "<svg viewBox=\"0 0 64 64\" id=\"svg5215\" sodipodi:docname=\"MP_0.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs5219\"><rect x=\"43.890084\" y=\"43.278375\" width=\"18.962963\" height=\"19.574671\" id=\"rect6750\"/></defs><sodipodi:namedview id=\"namedview5217\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"6.5390625\" inkscape:cx=\"12.540024\" inkscape:cy=\"60.100358\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"svg5215\" showguides=\"true\"><sodipodi:guide position=\"-25.844683,35.096774\" orientation=\"0,-1\" id=\"guide18180\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"g6490\"><polygon points=\"4,0 0,0 0,4 0,40 4,40 4,4 40,4 40,0\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"polygon5198\" transform=\"scale(1.4434886)\"/><rect x=\"8\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5200\"/><rect x=\"8\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5202\"/><rect x=\"24\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5204\"/><rect x=\"24\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#0d9be2\" id=\"rect5206\"/><rect x=\"39.502987\" y=\"8.0764637\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6468\"/><rect x=\"8.2293911\" y=\"39.216248\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6472\"/></g><g aria-label=\"0\" transform=\"matrix(2.8469125,0,0,2.8469125,-114.11747,-102.36809)\" id=\"text6748\" style=\"font-size:16px;white-space:pre;shape-inside:url(#rect6750);fill:#ff0;stroke-width:8.01;stroke-linejoin:bevel;paint-order:fill markers stroke\"><path d=\"m62.103516 52.11064q0 1.382813-.203125 2.476563-.195313 1.09375-.640625 1.851562-.4375.757813-1.132813 1.15625-.695312.398438-1.6875.398438-.921875.0-1.609375-.398438-.679687-.398437-1.132812-1.15625-.445313-.757812-.671875-1.851562-.21875-1.09375-.21875-2.476563.0-1.382812.195312-2.476562.203125-1.09375.632813-1.84375.4375-.757813 1.125-1.15625.695312-.398438 1.679687-.398438.929688.0 1.617188.398438.6875.390625 1.140625 1.148437.453125.75.679687 1.84375.226563 1.09375.226563 2.484375zm-5.851563.0q0 1.171875.117188 2.046875.117187.875.375 1.460938.257812.578125.671875.875.421875.289062 1.023437.289062.601563.0 1.023438-.289062.421875-.289063.6875-.867188.273437-.578125.390625-1.453125.125-.882812.125-2.0625.0-1.171875-.125-2.046875-.117188-.875-.390625-1.453125-.265625-.578125-.6875-.867187-.421875-.289063-1.023438-.289063-.601562.0-1.023437.289063-.414063.289062-.671875.867187-.257813.578125-.375 1.453125-.117188.875-.117188 2.046875z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path8325\"/></g></svg>";
        string _SVGIcon_PlacmentAngle_90 = "<svg viewBox=\"0 0 64 64\" id=\"svg5215\" sodipodi:docname=\"MP_90.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs5219\"><rect x=\"43.890084\" y=\"43.278375\" width=\"18.962963\" height=\"19.574671\" id=\"rect6750\"/></defs><sodipodi:namedview id=\"namedview5217\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"6.5390625\" inkscape:cx=\"25.080048\" inkscape:cy=\"60.100358\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"svg5215\" showguides=\"true\"><sodipodi:guide position=\"-7.0346476,35.096774\" orientation=\"0,-1\" id=\"guide12685\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"g6490\"><polygon points=\"4,0 0,0 0,4 0,40 4,40 4,4 40,4 40,0\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"polygon5198\" transform=\"scale(1.4434886)\"/><rect x=\"8\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5200\"/><rect x=\"8\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5202\"/><rect x=\"24\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5204\"/><rect x=\"24\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#0d9be2\" id=\"rect5206\"/><rect x=\"39.502987\" y=\"8.0764637\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6468\"/><rect x=\"8.2293911\" y=\"39.216248\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6472\"/></g><g aria-label=\"90\" transform=\"matrix(2.8729254,0,0,2.8729254,-115.73296,-103.87667)\" id=\"text6748\" style=\"font-size:16px;white-space:pre;shape-inside:url(#rect6750);display:inline;fill:#ff0;stroke-width:8.01;stroke-linejoin:bevel;paint-order:fill markers stroke\"><path d=\"m53.259766 51.290328q0 .820312-.08594 1.640625-.07813.8125-.289062 1.554687-.203125.742188-.5625 1.390625-.359375.640625-.914063 1.109375-.554687.46875-1.328125.742188-.773437.265625-1.8125.265625-.148437.0-.328125-.0078-.179687-.0078-.359375-.03125-.179687-.01563-.351562-.03906-.171875-.02344-.304688-.0625v-1.21875q.273438.101562.617188.148437.34375.04687.679687.04687 1.054688.0 1.734375-.367187.679688-.367188 1.078125-.992188.398438-.632812.5625-1.46875.171875-.835937.210938-1.765625h-.101563q-.15625.28125-.375.523438-.21875.242187-.515625.421875-.296875.179687-.671875.28125-.375.101562-.835937.101562-.742188.0-1.34375-.226562-.601563-.234375-1.023438-.679688-.421875-.445312-.65625-1.085937-.226562-.648438-.226562-1.476563.0-.890625.242187-1.601562.25-.71875.695313-1.210938.453125-.5 1.09375-.765625.648437-.265625 1.445312-.265625.789063.0 1.46875.304688.679688.304687 1.179688.929687t.789062 1.578125q.289063.945313.289063 2.226563zM49.548828 47.45439q-.46875.0-.859375.15625-.382812.15625-.664062.484375t-.4375.828125q-.148438.492188-.148438 1.171875.0.546875.125.984375.132813.429688.390625.734375.257813.304688.640625.46875.390625.164063.90625.164063.53125.0.960938-.179688.429687-.1875.734375-.476562.304687-.296875.46875-.671875.171875-.375.171875-.75.0-.523438-.148438-1.039063-.140625-.523437-.429687-.9375-.28125-.421875-.710938-.679687-.429687-.257813-1-.257813z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path8259\"/><path d=\"m62.103516 52.11064q0 1.382813-.203125 2.476563-.195313 1.09375-.640625 1.851562-.4375.757813-1.132813 1.15625-.695312.398438-1.6875.398438-.921875.0-1.609375-.398438-.679687-.398437-1.132812-1.15625-.445313-.757812-.671875-1.851562-.21875-1.09375-.21875-2.476563.0-1.382812.195312-2.476562.203125-1.09375.632813-1.84375.4375-.757813 1.125-1.15625.695312-.398438 1.679687-.398438.929688.0 1.617188.398438.6875.390625 1.140625 1.148437.453125.75.679687 1.84375.226563 1.09375.226563 2.484375zm-5.851563.0q0 1.171875.117188 2.046875.117187.875.375 1.460938.257812.578125.671875.875.421875.289062 1.023437.289062.601563.0 1.023438-.289062.421875-.289063.6875-.867188.273437-.578125.390625-1.453125.125-.882812.125-2.0625.0-1.171875-.125-2.046875-.117188-.875-.390625-1.453125-.265625-.578125-.6875-.867187-.421875-.289063-1.023438-.289063-.601562.0-1.023437.289063-.414063.289062-.671875.867187-.257813.578125-.375 1.453125-.117188.875-.117188 2.046875z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path8261\"/></g></svg>";
        string _SVGIcon_PlacmentAngle_180 = "<svg viewBox=\"0 0 64 64\" id=\"svg5215\" sodipodi:docname=\"MP_180.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs5219\"><rect x=\"43.890084\" y=\"43.278375\" width=\"29.249144\" height=\"19.262969\" id=\"rect6750\"/></defs><sodipodi:namedview id=\"namedview5217\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"6.5390625\" inkscape:cx=\"12.692951\" inkscape:cy=\"60.100358\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"svg5215\" showguides=\"true\"><sodipodi:guide position=\"-39.455197,35.096774\" orientation=\"0,-1\" id=\"guide13568\" inkscape:locked=\"false\"/></sodipodi:namedview><g id=\"g6490\"><polygon points=\"4,0 0,0 0,4 0,40 4,40 4,4 40,4 40,0\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"polygon5198\" transform=\"scale(1.4434886)\"/><rect x=\"8\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5200\"/><rect x=\"8\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5202\"/><rect x=\"24\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5204\"/><rect x=\"24\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#0d9be2\" id=\"rect5206\"/><rect x=\"39.502987\" y=\"8.0764637\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6468\"/><rect x=\"8.2293911\" y=\"39.216248\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6472\"/></g><g aria-label=\"180\" transform=\"matrix(2.5737776,0,0,2.5737776,-123.32269,-86.222199)\" id=\"text6748\" style=\"font-size:16px;white-space:pre;shape-inside:url(#rect6750);display:inline;fill:#ff0;stroke-width:8.01;stroke-linejoin:bevel;paint-order:fill markers stroke\"><path d=\"m52.255859 57.837203h-1.375V50.70439q0-.335937.0-.71875.0078-.382812.01563-.757812.01563-.382813.02344-.726563.01563-.351562.02344-.617187-.132812.140625-.234375.242187-.101562.101563-.210937.195313-.101563.09375-.21875.203125-.117188.101562-.28125.242187l-1.15625.945313-.75-.960938 2.992187-2.335937h1.171875z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path8190\"/><path d=\"m59.927734 46.23564q.65625.0 1.234375.171875.585938.171875 1.023438.515625.445312.34375.703125.859375.257812.515625.257812 1.203125.0.523438-.15625.945313t-.429687.765625q-.273438.335937-.648438.609375-.375.265625-.8125.484375.453125.242187.882813.539062.4375.296875.773437.671875.34375.367188.546875.828125.210938.460938.210938 1.03125.0.71875-.265625 1.304688-.257813.578125-.734375.984375-.46875.40625-1.132813.625-.65625.21875-1.453125.21875-.859375.0-1.53125-.210938-.664062-.210937-1.125-.601562-.453125-.398438-.695312-.96875-.234375-.570313-.234375-1.289063.0-.585937.171875-1.054687.179687-.46875.476562-.84375t.703125-.664063q.40625-.289062.859375-.507812-.382812-.242188-.71875-.523438-.335937-.289062-.585937-.640625-.242188-.351562-.390625-.773437-.140625-.429688-.140625-.945313.0-.679687.257812-1.1875.265625-.515625.710938-.859375.445312-.34375 1.023437-.515625.585938-.171875 1.21875-.171875zm-2.1875 8.703125q0 .414063.125.765625.125.34375.390625.59375.265625.242188.671875.382813.40625.132812.96875.132812.546875.0.960938-.132812.421875-.140625.703125-.390625.28125-.257813.421875-.617188t.140625-.796875q0-.40625-.15625-.734375-.148438-.328125-.4375-.609375-.28125-.28125-.679688-.53125-.398437-.25-.890625-.492187l-.234375-.109375q-.984375.46875-1.484375 1.078125-.5.601562-.5 1.460937zm2.171875-7.515625q-.828125.0-1.320312.414063-.484375.414062-.484375 1.203125.0.445312.132812.765625.140625.320312.382813.570312.242187.25.578125.453125.34375.195313.742187.382813.375-.171875.703125-.375.335938-.203125.578125-.460938.25-.257812.390625-.585937t.140625-.75q0-.789063-.492187-1.203125-.492188-.414063-1.351563-.414063zm3.15625 4.976563z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path8192\"/><path d=\"m72.388672 52.11064q0 1.382813-.203125 2.476563-.195313 1.09375-.640625 1.851562-.4375.757813-1.132813 1.15625-.695312.398438-1.6875.398438-.921875.0-1.609375-.398438-.679687-.398437-1.132812-1.15625-.445313-.757812-.671875-1.851562-.21875-1.09375-.21875-2.476563.0-1.382812.195312-2.476562.203125-1.09375.632813-1.84375.4375-.757813 1.125-1.15625.695312-.398438 1.679687-.398438.929688.0 1.617188.398438.6875.390625 1.140625 1.148437.453125.75.679687 1.84375.226563 1.09375.226563 2.484375zm-5.851563.0q0 1.171875.117188 2.046875.117187.875.375 1.460938.257812.578125.671875.875.421875.289062 1.023437.289062.601563.0 1.023438-.289062.421875-.289063.6875-.867188.273437-.578125.390625-1.453125.125-.882812.125-2.0625.0-1.171875-.125-2.046875-.117188-.875-.390625-1.453125-.265625-.578125-.6875-.867187-.421875-.289063-1.023438-.289063-.601562.0-1.023437.289063-.414063.289062-.671875.867187-.257813.578125-.375 1.453125-.117188.875-.117188 2.046875z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path8194\"/></g></svg>";
        string _SVGIcon_PlacmentAngle_270 = "<svg viewBox=\"0 0 64 64\" id=\"svg5215\" sodipodi:docname=\"MP_270.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs5219\"><rect x=\"43.890084\" y=\"43.278375\" width=\"29.249144\" height=\"19.262969\" id=\"rect6750\"/></defs><sodipodi:namedview id=\"namedview5217\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"6.5390625\" inkscape:cx=\"12.692951\" inkscape:cy=\"60.100358\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"svg5215\"/><g id=\"g6490\"><polygon points=\"4,0 0,0 0,4 0,40 4,40 4,4 40,4 40,0\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"polygon5198\" transform=\"scale(1.4434886)\"/><rect x=\"8\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5200\"/><rect x=\"8\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5202\"/><rect x=\"24\" y=\"8\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect5204\"/><rect x=\"24\" y=\"24\" width=\"12\" height=\"12\" style=\"fill:#0d9be2\" id=\"rect5206\"/><rect x=\"39.502987\" y=\"8.0764637\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6468\"/><rect x=\"8.2293911\" y=\"39.216248\" width=\"12\" height=\"12\" style=\"fill:#bbbdbd;fill-opacity:1\" id=\"rect6472\"/></g><g aria-label=\"270\" transform=\"matrix(2.5087455,0,0,2.5087455,-118.6151,-82.450761)\" id=\"text6748\" style=\"font-size:16px;white-space:pre;shape-inside:url(#rect6750);display:inline;fill:#ff0;stroke-width:8.01;stroke-linejoin:bevel;paint-order:fill markers stroke\"><path d=\"m54.576172 57.837203h-7.125v-1.21875l2.734375-2.976563q.585937-.632812 1.046875-1.15625.460937-.523437.78125-1.023437.328125-.5.5-1 .171875-.507813.171875-1.101563.0-.460937-.132813-.8125-.132812-.351562-.382812-.59375-.242188-.25-.578125-.375-.335938-.125-.75-.125-.742188.0-1.34375.304688-.59375.296875-1.132813.765625l-.796875-.929688q.3125-.28125.671875-.523437.359375-.25.773438-.429688.414062-.179687.875-.28125.460937-.109375.96875-.109375.75.0 1.351562.210938.609375.210937 1.03125.609375.421875.390625.648438.960937.234375.5625.234375 1.273438.0.664062-.210938 1.265625-.203125.601562-.570312 1.1875-.359375.578125-.867188 1.164062-.5.585938-1.085937 1.21875l-2.195313 2.335938v.0625h5.382813z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path7666\"/><path d=\"m57.708984 57.837203 4.398438-10.125h-5.890625v-1.296875h7.34375v1.132812l-4.335938 10.289063z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path7668\"/><path d=\"m72.388672 52.11064q0 1.382813-.203125 2.476563-.195313 1.09375-.640625 1.851562-.4375.757813-1.132813 1.15625-.695312.398438-1.6875.398438-.921875.0-1.609375-.398438-.679687-.398437-1.132812-1.15625-.445313-.757812-.671875-1.851562-.21875-1.09375-.21875-2.476563.0-1.382812.195312-2.476562.203125-1.09375.632813-1.84375.4375-.757813 1.125-1.15625.695312-.398438 1.679687-.398438.929688.0 1.617188.398438.6875.390625 1.140625 1.148437.453125.75.679687 1.84375.226563 1.09375.226563 2.484375zm-5.851563.0q0 1.171875.117188 2.046875.117187.875.375 1.460938.257812.578125.671875.875.421875.289062 1.023437.289062.601563.0 1.023438-.289062.421875-.289063.6875-.867188.273437-.578125.390625-1.453125.125-.882812.125-2.0625.0-1.171875-.125-2.046875-.117188-.875-.390625-1.453125-.265625-.578125-.6875-.867187-.421875-.289063-1.023438-.289063-.601562.0-1.023437.289063-.414063.289062-.671875.867187-.257813.578125-.375 1.453125-.117188.875-.117188 2.046875z\" style=\"text-align:end;text-anchor:end;fill:red\" id=\"path7670\"/></g></svg>";

        string _SVGIcon_ApplyData_FromPart = "<svg id=\"Einfügen_2D\" data-name=\"Einfügen 2D\" viewBox=\"0 0 64 64\" sodipodi:docname=\"MP_SizeFromArticle.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs29721\"><rect x=\"67.909285\" y=\"16.436642\" width=\"26.817679\" height=\"28.223445\" id=\"rect38176\"/><rect x=\"67.044198\" y=\"4.3254322\" width=\"28.223445\" height=\"28.655988\" id=\"rect37389\"/></defs><sodipodi:namedview id=\"namedview29719\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"9.2476309\" inkscape:cx=\"25.195642\" inkscape:cy=\"36.658037\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Betriebsmittel\"/><g id=\"Betriebsmittel\"><g id=\"g30225\" transform=\"matrix(1.3170557,0,0,1.3170557,12.302788,9.0926378)\" inkscape:label=\"Einkaufswagen\"><path d=\"M30.354563 20.236375 32.88411 5.0590938H7.9743967L7.5886408 2.1690865 7.2534758.0H0V2.5295469H5.0590938L7.5886408 20.236375zm-2.143791-2.529547H9.7830227L9.0621018 12.647735H29.051846zM12.647735 7.5886408h17.25151l-.4237 2.5295472H8.6953175L8.3348571 7.5886408z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.632387\" id=\"path29705\"/><path d=\"m11.382961 22.765922a3.7943204 3.7943204.0 103.794321 3.794321 3.7943204 3.7943204.0 00-3.794321-3.794321zm0 5.059094a1.2647735 1.2647735.0 111.264774-1.264773 1.2647735 1.2647735.0 01-1.264774 1.264773z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.632387\" id=\"path29709\"/><path d=\"m26.566287 22.765922a3.7943204 3.7943204.0 103.79432 3.794321 3.7943204 3.7943204.0 00-3.79432-3.794321zm0 5.059094a1.2647735 1.2647735.0 111.264773-1.264773 1.2647735 1.2647735.0 01-1.264773 1.264773z\" style=\"display:inline;fill:#bbbdbd;fill-opacity:1;stroke-width:.632387\" id=\"path30216\"/></g><g id=\"g36631\" transform=\"matrix(0,-1.2186688,1,0,-49.382289,69.706581)\" style=\"fill:#00f\" inkscape:label=\"Y-Axis\"><rect style=\"fill:#00f;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36627\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36629\" style=\"fill:#00f;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><g id=\"g36637\" transform=\"matrix(1.2186688,0,0,1,-9.7152097,0.70858752)\" style=\"fill:red\" inkscape:label=\"X-Axis\"><rect style=\"fill:red;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36633\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36635\" style=\"fill:red;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g></g></svg>";
        string _SVGIcon_ApplyData_FromPartAndMacro = "<svg id=\"Einfügen_2D\" data-name=\"Einfügen 2D\" viewBox=\"0 0 64 64\" sodipodi:docname=\"MP_SizeFromMacroAndArcticle.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs29721\"><rect x=\"67.909285\" y=\"16.436642\" width=\"26.817679\" height=\"28.223445\" id=\"rect38176\"/><rect x=\"67.044198\" y=\"4.3254322\" width=\"28.223445\" height=\"28.655988\" id=\"rect37389\"/></defs><sodipodi:namedview id=\"namedview29719\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"9.2476309\" inkscape:cx=\"25.195642\" inkscape:cy=\"36.658037\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Betriebsmittel\"/><g id=\"Betriebsmittel\"><g id=\"g30225\" transform=\"translate(28.523159,2.3882168)\" inkscape:label=\"Einkaufswagen\"><path d=\"M30.354563 20.236375 32.88411 5.0590938H7.9743967L7.5886408 2.1690865 7.2534758.0H0V2.5295469H5.0590938L7.5886408 20.236375zm-2.143791-2.529547H9.7830227L9.0621018 12.647735H29.051846zM12.647735 7.5886408h17.25151l-.4237 2.5295472H8.6953175L8.3348571 7.5886408z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.632387\" id=\"path29705\"/><path d=\"m11.382961 22.765922a3.7943204 3.7943204.0 103.794321 3.794321 3.7943204 3.7943204.0 00-3.794321-3.794321zm0 5.059094a1.2647735 1.2647735.0 111.264774-1.264773 1.2647735 1.2647735.0 01-1.264774 1.264773z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.632387\" id=\"path29709\"/><path d=\"m26.566287 22.765922a3.7943204 3.7943204.0 103.79432 3.794321 3.7943204 3.7943204.0 00-3.79432-3.794321zm0 5.059094a1.2647735 1.2647735.0 111.264773-1.264773 1.2647735 1.2647735.0 01-1.264773 1.264773z\" style=\"display:inline;fill:#bbbdbd;fill-opacity:1;stroke-width:.632387\" id=\"path30216\"/></g><g id=\"g36631\" transform=\"matrix(0,-1.2186688,1,0,-49.382289,69.706581)\" style=\"fill:#00f\" inkscape:label=\"Y-Axis\"><rect style=\"fill:#00f;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36627\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36629\" style=\"fill:#00f;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><g id=\"g36637\" transform=\"matrix(1.2186688,0,0,1,-9.7152097,0.70858752)\" style=\"fill:red\" inkscape:label=\"X-Axis\"><rect style=\"fill:red;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36633\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36635\" style=\"fill:red;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><g aria-label=\"+\" transform=\"matrix(1.3776873,0,0,1.3776873,-85.79119,-8.4599873)\" id=\"text37387\" style=\"font-size:24px;text-align:center;text-anchor:middle;white-space:pre;shape-inside:url(#rect37389);fill:#0d9be2;stroke-width:7.01;stroke-linejoin:bevel;paint-order:fill markers stroke\" inkscape:label=\"+\"><path d=\"M80.277344 19.307562H75.742187V17.54975h4.535157v-4.546875h1.757812v4.546875h4.535156v1.757812H82.035156V23.831h-1.757812zm-.421875-8.074219z\" id=\"path38119\"/></g><g id=\"g41350\" inkscape:label=\"Macro\" transform=\"matrix(0.57867322,0,0,0.57867322,2.7077678,25.344849)\"><polygon points=\"18,12 18,16 24,16 24,26 28,26 28,12\" style=\"fill:#e2001a\" id=\"polygon40705\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"46,12 36,12 36,26 40,26 40,16 46,16\" style=\"fill:#e2001a\" id=\"polygon40707\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"40,48 40,38 36,38 36,52 46,52 46,48\" style=\"fill:#e2001a\" id=\"polygon40709\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"24,38 24,48 18,48 18,52 28,52 28,38\" style=\"fill:#e2001a\" id=\"polygon40711\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><path d=\"M13.741445 2.2790497V48.22037H59.682766V2.2790497zM56.811433 45.349037H16.612778V5.1503822h40.198655z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.717833\" id=\"path40715\"/><path d=\"M28.098108 8.0217147H19.48411v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40717\"/><path d=\"M28.098108 33.863707H19.48411v8.613998h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40719\"/><path d=\"m45.326103 42.477705h8.613998v-8.613998h-8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40721\"/><path d=\"m53.940101 8.0217147h-8.613998v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40723\"/><path d=\"M28.098108 30.992375H45.326103V19.507045H28.098108zm2.871332-8.613998h11.48533v5.742665H30.96944z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.717833\" id=\"path40725\"/></g></g></svg>";
        string _SVGIcon_ApplyData_FromMacro = "<svg id=\"Einfügen_2D\" data-name=\"Einfügen 2D\" viewBox=\"0 0 64 64\" sodipodi:docname=\"MP_SizeMacro.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs29721\"><rect x=\"67.909285\" y=\"16.436642\" width=\"26.817679\" height=\"28.223445\" id=\"rect38176\"/><rect x=\"67.044198\" y=\"4.3254322\" width=\"28.223445\" height=\"28.655988\" id=\"rect37389\"/></defs><sodipodi:namedview id=\"namedview29719\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"9.2476309\" inkscape:cx=\"25.195642\" inkscape:cy=\"19.248173\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Betriebsmittel\"/><g id=\"Betriebsmittel\"><g id=\"g36631\" transform=\"matrix(0,-1.2186688,1,0,-49.382289,69.706581)\" style=\"fill:#00f\" inkscape:label=\"Y-Axis\"><rect style=\"fill:#00f;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36627\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36629\" style=\"fill:#00f;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><g id=\"g36637\" transform=\"matrix(1.2186688,0,0,1,-9.7152097,0.70858752)\" style=\"fill:red\" inkscape:label=\"X-Axis\"><rect style=\"fill:red;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36633\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36635\" style=\"fill:red;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><g id=\"g41350\" inkscape:label=\"Macro\"><polygon points=\"18,16 24,16 24,26 28,26 28,12 18,12\" style=\"fill:#e2001a\" id=\"polygon40705\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"36,12 36,26 40,26 40,16 46,16 46,12\" style=\"fill:#e2001a\" id=\"polygon40707\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"40,38 36,38 36,52 46,52 46,48 40,48\" style=\"fill:#e2001a\" id=\"polygon40709\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"24,48 18,48 18,52 28,52 28,38 24,38\" style=\"fill:#e2001a\" id=\"polygon40711\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><path d=\"M13.741445 2.2790497V48.22037H59.682766V2.2790497zM56.811433 45.349037H16.612778V5.1503822h40.198655z\" style=\"fill:#bbbdbd;stroke-width:.717833;fill-opacity:1\" id=\"path40715\"/><path d=\"M28.098108 8.0217147H19.48411v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40717\"/><path d=\"M28.098108 33.863707H19.48411v8.613998h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40719\"/><path d=\"m45.326103 42.477705h8.613998v-8.613998h-8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40721\"/><path d=\"m53.940101 8.0217147h-8.613998v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40723\"/><path d=\"M28.098108 30.992375H45.326103V19.507045H28.098108zm2.871332-8.613998h11.48533v5.742665H30.96944z\" style=\"fill:#bbbdbd;stroke-width:.717833;fill-opacity:1\" id=\"path40725\"/></g></g></svg>";
        string _SVGIcon_ApplyData_ManualInput = "<svg id=\"Einfügen_2D\" data-name=\"Einfügen 2D\" viewBox=\"0 0 64 64\" sodipodi:docname=\"MP_SizeManual.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs29721\"><rect x=\"67.909285\" y=\"16.436642\" width=\"26.817679\" height=\"28.223445\" id=\"rect38176\"/><rect x=\"67.044198\" y=\"4.3254322\" width=\"28.223445\" height=\"28.655988\" id=\"rect37389\"/></defs><sodipodi:namedview id=\"namedview29719\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"9.2476309\" inkscape:cx=\"25.195642\" inkscape:cy=\"36.658037\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Betriebsmittel\"/><g id=\"Betriebsmittel\"><g id=\"g36631\" transform=\"matrix(0,-1.2186688,1,0,-49.382289,69.706581)\" style=\"fill:#00f\" inkscape:label=\"Y-Axis\"><rect style=\"fill:#00f;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36627\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36629\" style=\"fill:#00f;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><g id=\"g36637\" transform=\"matrix(1.2186688,0,0,1,-9.7152097,0.70858752)\" style=\"fill:red\" inkscape:label=\"X-Axis\"><rect style=\"fill:red;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36633\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36635\" style=\"fill:red;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><path d=\"m41.305828 14.169889-20 20-4 12 12-4 20-20zm2.34 8-1.75 1.76-2.35-2.35 1.76-1.75zm-16.5 16.5-3.52 1.18 1.18-3.52 11.91-11.92 2.35 2.35z\" style=\"fill:#0d9be2\" id=\"path33363\" inkscape:label=\"Pencil\"/></g></svg>";
        string _SVGIcon_ApplyData_ManualInputAndMacro = "<svg id=\"Einfügen_2D\" data-name=\"Einfügen 2D\" viewBox=\"0 0 64 64\" sodipodi:docname=\"MP_SizeManual+Macro.svg\" inkscape:version=\"1.2.2 (732a01da63, 2022-12-09)\" xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\"><defs id=\"defs29721\"><rect x=\"67.909285\" y=\"16.436642\" width=\"26.817679\" height=\"28.223445\" id=\"rect38176\"/><rect x=\"67.044198\" y=\"4.3254322\" width=\"28.223445\" height=\"28.655988\" id=\"rect37389\"/></defs><sodipodi:namedview id=\"namedview29719\" pagecolor=\"#ffffff\" bordercolor=\"#000000\" borderopacity=\".25\" inkscape:showpageshadow=\"2\" inkscape:pageopacity=\"0\" inkscape:pagecheckerboard=\"0\" inkscape:deskcolor=\"#d1d1d1\" showgrid=\"false\" inkscape:zoom=\"9.2476309\" inkscape:cx=\"25.195642\" inkscape:cy=\"18.599358\" inkscape:window-width=\"1920\" inkscape:window-height=\"1017\" inkscape:window-x=\"1912\" inkscape:window-y=\"-8\" inkscape:window-maximized=\"1\" inkscape:current-layer=\"Betriebsmittel\"/><g id=\"Betriebsmittel\"><g id=\"g36631\" transform=\"matrix(0,-1.2186688,1,0,-49.382289,69.706581)\" style=\"fill:#00f\" inkscape:label=\"Y-Axis\"><rect style=\"fill:#00f;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36627\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36629\" style=\"fill:#00f;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><g id=\"g36637\" transform=\"matrix(1.2186688,0,0,1,-9.7152097,0.70858752)\" style=\"fill:red\" inkscape:label=\"X-Axis\"><rect style=\"fill:red;stroke-width:7.61285;stroke-linejoin:bevel;paint-order:fill markers stroke\" id=\"rect36633\" width=\"33.982029\" height=\"4.7407427\" x=\"11.769418\" y=\"54.110622\" rx=\".16936785\" ry=\"1.3818361\"/><path id=\"path36635\" style=\"fill:red;stroke-width:8.99975;stroke-linejoin:bevel;paint-order:fill markers stroke\" d=\"m44.435167 49.912178v12.409199l7.344785-5.825546c.09259-.07345-1.197658-1.344804-2.892893-2.851442L47.567538 52.47204c-1.488191-1.322629-2.776605-2.372628-3.132371-2.559862z\"/></g><g aria-label=\"+\" transform=\"matrix(1.3776873,0,0,1.3776873,-85.79119,-8.4599873)\" id=\"text37387\" style=\"font-size:24px;text-align:center;text-anchor:middle;white-space:pre;shape-inside:url(#rect37389);fill:#0d9be2;stroke-width:7.01;stroke-linejoin:bevel;paint-order:fill markers stroke\" inkscape:label=\"+\"><path d=\"M80.277344 19.307562H75.742187V17.54975h4.535157v-4.546875h1.757812v4.546875h4.535156v1.757812H82.035156V23.831h-1.757812zm-.421875-8.074219z\" id=\"path38119\"/></g><path d=\"M56.742214.65291356 40.459383 16.935746l-3.256567 9.769699 9.769699-3.256567L63.255347 7.1660463zM58.647306 7.1660463 57.222558 8.5989358l-1.913233-1.913233L56.742214 5.260955zM45.213969 20.599383l-2.865778.960687.960687-2.865779 9.696426-9.7045672 1.913233 1.9132332z\" style=\"fill:#0d9be2;stroke-width:.814142\" id=\"path33363\" inkscape:label=\"Pencil\"/><g id=\"g41350\" inkscape:label=\"Macro\" transform=\"matrix(0.57867322,0,0,0.57867322,2.6537003,25.29078)\"><polygon points=\"18,16 24,16 24,26 28,26 28,12 18,12\" style=\"fill:#e2001a\" id=\"polygon40705\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"36,12 36,26 40,26 40,16 46,16 46,12\" style=\"fill:#e2001a\" id=\"polygon40707\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"40,38 36,38 36,52 46,52 46,48 40,48\" style=\"fill:#e2001a\" id=\"polygon40709\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><polygon points=\"24,48 18,48 18,52 28,52 28,38 24,38\" style=\"fill:#e2001a\" id=\"polygon40711\" transform=\"matrix(0.71783314,0,0,0.71783314,13.741445,2.2790497)\"/><path d=\"M13.741445 2.2790497V48.22037H59.682766V2.2790497zM56.811433 45.349037H16.612778V5.1503822h40.198655z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.717833\" id=\"path40715\"/><path d=\"M28.098108 8.0217147H19.48411v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40717\"/><path d=\"M28.098108 33.863707H19.48411v8.613998h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40719\"/><path d=\"m45.326103 42.477705h8.613998v-8.613998h-8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40721\"/><path d=\"m53.940101 8.0217147h-8.613998v8.6139973h8.613998z\" style=\"fill:#0d9be2;stroke-width:.717833\" id=\"path40723\"/><path d=\"M28.098108 30.992375H45.326103V19.507045H28.098108zm2.871332-8.613998h11.48533v5.742665H30.96944z\" style=\"fill:#bbbdbd;fill-opacity:1;stroke-width:.717833\" id=\"path40725\"/></g></g></svg>";

        #endregion

        #endregion


        [DeclareAction("2D_TogglePlacementDirection")]
        public void SetUserPlacementDirection()
        {            
            Settings oSettings = new Settings();
            string _ActualDirection = oSettings.GetStringSetting("USER.PanelLayoutGui.Settings.Direction", 0);
            if(_ActualDirection.ToUpper() == "HORIZONTAL")
            {
                oSettings.SetStringSetting("USER.PanelLayoutGui.Settings.Direction", "Vertical", 0);
            }
            else 
            {
                oSettings.SetStringSetting("USER.PanelLayoutGui.Settings.Direction", "Horizontal", 0);
            }            
            this.CreateRibbonMenu();
        }
        
        [DeclareAction("2D_SetRotationAngle")]
        public void SetUserRotationAngle(string angle)
        {
            Settings oSettings = new Settings();
            oSettings.SetDoubleSetting("USER.PanelLayoutGui.Settings.RotationAngle", System.Convert.ToDouble(angle), 0);
            this.CreateRibbonMenu();
        }

        [DeclareAction("2D_SetGripperPosition")]
        public void SetUserGripperPosition(string position)
        {
            Settings oSettings = new Settings();
            oSettings.SetStringSetting("USER.PanelLayoutGui.Settings.Gripper", position, 0);
            this.CreateRibbonMenu();
        }
        

        [DeclareAction("2D_ToggleGripperFromMacro")]
        public void SetUserGripperFromMacro()
        {
            Settings oSettings = new Settings();            
            oSettings.SetBoolSetting("USER.PanelLayoutGui.Settings.GripperFromMacro", !oSettings.GetBoolSetting("USER.PanelLayoutGui.Settings.GripperFromMacro", 0), 0);
            this.CreateRibbonMenu();
        }

        [DeclareAction("2D_SetDataOvertaking")]
        public void SetUserDataOvertaking(string data_from)
        {
            Settings oSettings = new Settings();
            oSettings.SetStringSetting("USER.PanelLayoutGui.Settings.DataOvertaking", data_from, 0);
            this.CreateRibbonMenu();
        }


        [DeclareAction("2DMountingPanelHelper_PopUpMenu")]
        public bool MountingPanelHelper_PopUpMenu_ActionPopUpMenu(ActionCallingContext acc)
        {
            // Get items
            string itemsString = null;
            acc.GetParameter("Items", ref itemsString);

            if (string.IsNullOrEmpty(itemsString))
            {
                return false;
            }
            ContextMenuStrip menu = new ContextMenuStrip();
            var itemsSplit = itemsString.Split('|');
            foreach (var itemSplit in itemsSplit)
            {
                var split = itemSplit.Split(';');
                if (split.Length < 2)
                {
                    new Decider().Decide(EnumDecisionType.eOkDecision, "Wrong parameter value.", "EPLAN_2DMountingPanelHelper.cs",
                                         EnumDecisionReturn.eOK, EnumDecisionReturn.eOK, "EPLAN_2DMountingPanelHelper.cs", false,
                                         EnumDecisionIcon.eFATALERROR);
                    return false;
                }
                // Create item
                ToolStripMenuItem menuItem = new ToolStripMenuItem();
                string text = split[0];
                menuItem.Text = text;
                // Action
                string action = split[1];
                menuItem.Click += (sender, args) => { new CommandLineInterpreter().Execute(action); };
                // Tooltip
                if (split.Length > 2)
                {
                    string tooltipText = split[2];
                    menuItem.ToolTipText = tooltipText;
                }
                menu.Items.Add(menuItem);
            }
            menu.Show(Cursor.Position);
            return true;
        }

        [DeclareRegister]
        public void Register_EPLAN_2DMountingPanelHelper()
        {
            this.CreateRibbonMenu();
        }

        [DeclareUnregister]
        public void Unregister_EPLAN_2DMountingPanelHelper()
        {
            this.RemoveRibbonMenu();
        }

        [DeclareEventHandler("Eplan.EplApi.OnMainStart")]
        public void EPLANStart()
        {
            //create Ribbon on EPLAN start
            this.CreateRibbonMenu();
        }

        [DeclareEventHandler("Eplan.EplApi.OnMainEnd")]
        public void EPLANEnd()
        {
            this.RemoveRibbonMenu();
        }

        public void CreateRibbonMenu()
        {
            //ensure correct defined multi-languagestring for ribbon name
            this.InitializeRibbonText();

            //due to restrictions of BCGSoft, if new multi-language Ribbon gets added, complete removal has to be done first
            this.RemoveRibbonMenu();

            RibbonBar ribbonBar = new RibbonBar();
            RibbonTab ribbonTab = ribbonBar.GetTab(global_mls_RibbOwnTabName, true);

            if (ribbonTab != null)
            {                
                string _FullMappingFileName = string.Empty;
                string _CommandCall = string.Empty;

                var _commandGroup1 = ribbonTab.AddCommandGroup(global_mls_CommandGroupName1);                
                if (_commandGroup1 != null)
                {
                    Settings oSettings = new Settings();
                    #region placement direction
                    if (oSettings.GetStringSetting("USER.PanelLayoutGui.Settings.Direction", 0).ToUpper() == "HORIZONTAL")
                    {
                        _commandGroup1.AddCommand(string.Empty, "2D_TogglePlacementDirection", ribbonBar.AddIcon(_SVG_Icon_PlacementDirection_Horizontal));
                    }
                    else
                    {
                        _commandGroup1.AddCommand(string.Empty, "2D_TogglePlacementDirection", ribbonBar.AddIcon(_SVG_Icon_PlacementDirection_Vertical));
                    }
                    #endregion

                    #region rotation angle

                    #region provide language depending text(s)
                    MultiLangString mlsRotationAngle = new MultiLangString();
                    mlsRotationAngle.AddString(ISOCode.Language.L_de_DE, "Artikelplatzierung: Drewhinkel ");
                    mlsRotationAngle.AddString(ISOCode.Language.L_en_US, "Part placement: Angle ");
                    string _sRotationAngle = mlsRotationAngle.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sRotationAngle))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sRotationAngle = mlsRotationAngle.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    double _ActualRotationAngle =  oSettings.GetDoubleSetting("USER.PanelLayoutGui.Settings.RotationAngle", 0);
                    if(_ActualRotationAngle == 0)
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\"" + _sRotationAngle + "90°;2D_SetRotationAngle /angle:90;"+ _sRotationAngle +" 90°|"+_sRotationAngle+"180°;2D_SetRotationAngle /angle:180;"+_sRotationAngle+"180°|"+_sRotationAngle+"270°;2D_SetRotationAngle /angle:270;"+_sRotationAngle+"270°" + "\"";                        
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_PlacmentAngle_0));
                    }
                    else if (_ActualRotationAngle == 90)
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\"" + _sRotationAngle + "0°;2D_SetRotationAngle /angle:0;"+_sRotationAngle+"0°|"+_sRotationAngle+"180°;2D_SetRotationAngle /angle:180;"+_sRotationAngle+"180°|"+_sRotationAngle+"270°;2D_SetRotationAngle /angle:270;"+_sRotationAngle+"270°" + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_PlacmentAngle_90));
                    }
                    else if (_ActualRotationAngle == 180)
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\"" + _sRotationAngle + "0°;2D_SetRotationAngle /angle:0;"+_sRotationAngle+"0°|"+_sRotationAngle+"90°;2D_SetRotationAngle /angle:90;"+_sRotationAngle+"90°|"+_sRotationAngle+"270°;2D_SetRotationAngle /angle:270;"+_sRotationAngle+"270°" + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_PlacmentAngle_180));
                    }
                    else if (_ActualRotationAngle == 270)
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\"" + _sRotationAngle+"0°;2D_SetRotationAngle /angle:0;"+_sRotationAngle+"0°|"+_sRotationAngle+"90°;2D_SetRotationAngle /angle:90;"+_sRotationAngle+"90°|"+_sRotationAngle+"180°;2D_SetRotationAngle /angle:180;"+_sRotationAngle+"180°" + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_PlacmentAngle_270));
                    }

                    #endregion

                    #region handle position 

                    #region provide language depending text(s)
                    #region HandlePrefix
                    MultiLangString mlsHandlePosition_Prefix = new MultiLangString();
                    mlsHandlePosition_Prefix.AddString(ISOCode.Language.L_de_DE, "Anfasspunkt: ");
                    mlsHandlePosition_Prefix.AddString(ISOCode.Language.L_en_US, "Handle: ");
                    string _sHandlePosition_Prefix = mlsHandlePosition_Prefix.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_Prefix))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_Prefix = mlsHandlePosition_Prefix.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region UpperLeft
                    MultiLangString mlsHandlePosition_UpperLeft = new MultiLangString();
                    mlsHandlePosition_UpperLeft.AddString(ISOCode.Language.L_de_DE, "Oben links");
                    mlsHandlePosition_UpperLeft.AddString(ISOCode.Language.L_en_US, "Upper left");
                    string _sHandlePosition_UpperLeft = mlsHandlePosition_UpperLeft.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_UpperLeft))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_UpperLeft = mlsHandlePosition_UpperLeft.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region UpperCenter
                    MultiLangString mlsHandlePosition_UpperCenter = new MultiLangString();
                    mlsHandlePosition_UpperCenter.AddString(ISOCode.Language.L_de_DE, "Oben Mitte");
                    mlsHandlePosition_UpperCenter.AddString(ISOCode.Language.L_en_US, "Upper center");
                    string _sHandlePosition_UpperCenter = mlsHandlePosition_UpperCenter.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_UpperCenter))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_UpperCenter = mlsHandlePosition_UpperCenter.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region UpperRight
                    MultiLangString mlsHandlePosition_UpperRight = new MultiLangString();
                    mlsHandlePosition_UpperRight.AddString(ISOCode.Language.L_de_DE, "Oben rechts");
                    mlsHandlePosition_UpperRight.AddString(ISOCode.Language.L_en_US, "Upper right");
                    string _sHandlePosition_UpperRight = mlsHandlePosition_UpperRight.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_UpperRight))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_UpperRight = mlsHandlePosition_UpperRight.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region MiddleLeft
                    MultiLangString mlsHandlePosition_MiddleLeft = new MultiLangString();
                    mlsHandlePosition_MiddleLeft.AddString(ISOCode.Language.L_de_DE, "Mitte links");
                    mlsHandlePosition_MiddleLeft.AddString(ISOCode.Language.L_en_US, "Middle left");
                    string _sHandlePosition_MiddleLeft = mlsHandlePosition_MiddleLeft.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_MiddleLeft))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_MiddleLeft = mlsHandlePosition_MiddleLeft.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region Center
                    MultiLangString mlsHandlePosition_Center = new MultiLangString();
                    mlsHandlePosition_Center.AddString(ISOCode.Language.L_de_DE, "Mitte");
                    mlsHandlePosition_Center.AddString(ISOCode.Language.L_en_US, "Center");
                    string _sHandlePosition_Center = mlsHandlePosition_Center.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_Center))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_Center = mlsHandlePosition_Center.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region MiddleRight
                    MultiLangString mlsHandlePosition_MiddleRight = new MultiLangString();
                    mlsHandlePosition_MiddleRight.AddString(ISOCode.Language.L_de_DE, "Mitte rechts");
                    mlsHandlePosition_MiddleRight.AddString(ISOCode.Language.L_en_US, "Middle right");
                    string _sHandlePosition_MiddleRight = mlsHandlePosition_MiddleRight.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_MiddleLeft))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_MiddleRight = mlsHandlePosition_MiddleRight.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region LowerLeft
                    MultiLangString mlsHandlePosition_LowerLeft = new MultiLangString();
                    mlsHandlePosition_LowerLeft.AddString(ISOCode.Language.L_de_DE, "Unten links");
                    mlsHandlePosition_LowerLeft.AddString(ISOCode.Language.L_en_US, "Lower left");
                    string _sHandlePosition_LowerLeft = mlsHandlePosition_LowerLeft.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_LowerLeft))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_LowerLeft = mlsHandlePosition_LowerLeft.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region LowerCenter
                    MultiLangString mlsHandlePosition_LowerCenter = new MultiLangString();
                    mlsHandlePosition_LowerCenter.AddString(ISOCode.Language.L_de_DE, "Unten Mitte");
                    mlsHandlePosition_LowerCenter.AddString(ISOCode.Language.L_en_US, "Lower center");
                    string _sHandlePosition_LowerCenter = mlsHandlePosition_LowerCenter.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_LowerCenter))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_LowerCenter = mlsHandlePosition_LowerCenter.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region LowerRight
                    MultiLangString mlsHandlePosition_LowerRight = new MultiLangString();
                    mlsHandlePosition_LowerRight.AddString(ISOCode.Language.L_de_DE, "Unten rechts");
                    mlsHandlePosition_LowerRight.AddString(ISOCode.Language.L_en_US, "Lower right");
                    string _sHandlePosition_LowerRight = mlsHandlePosition_LowerRight.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sHandlePosition_LowerRight))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sHandlePosition_LowerRight = mlsHandlePosition_LowerRight.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion
                    #endregion

                    string _ActualHandlePostion = oSettings.GetStringSetting("USER.PanelLayoutGui.Settings.Gripper", 0);
                    if (_ActualHandlePostion.ToUpper() == "UPPERLEFT")
                    {                        
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\"" 
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + ";2D_SetGripperPosition /position:UpperCenter;" + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + "|" 
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperRight  + ";2D_SetGripperPosition /position:UpperRight;"  + _sHandlePosition_Prefix + _sHandlePosition_UpperRight  + "|" 
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft  + ";2D_SetGripperPosition /position:CenterLeft;"  + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft  + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_Center      + ";2D_SetGripperPosition /position:Center;"      + _sHandlePosition_Prefix + _sHandlePosition_Center      + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + ";2D_SetGripperPosition /position:CenterRight;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft   + ";2D_SetGripperPosition /position:LowerLeft;"   + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft   + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + ";2D_SetGripperPosition /position:LowerCenter;" + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerRight  + ";2D_SetGripperPosition /position:LowerRight;"  + _sHandlePosition_Prefix + _sHandlePosition_LowerRight
                            + "\"";                                                
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_UpperLeft));
                    }
                    else if (_ActualHandlePostion.ToUpper() == "UPPERCENTER")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft   + ";2D_SetGripperPosition /position:UpperLeft;"   + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperRight  + ";2D_SetGripperPosition /position:UpperRight;"  + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft  + ";2D_SetGripperPosition /position:CenterLeft;"  + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_Center      + ";2D_SetGripperPosition /position:Center;"      + _sHandlePosition_Prefix + _sHandlePosition_Center + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + ";2D_SetGripperPosition /position:CenterRight;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft   + ";2D_SetGripperPosition /position:LowerLeft;"   + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + ";2D_SetGripperPosition /position:LowerCenter;" + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerRight  + ";2D_SetGripperPosition /position:LowerRight;"  + _sHandlePosition_Prefix + _sHandlePosition_LowerRight
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_UpperCenter));
                    }
                    else if (_ActualHandlePostion.ToUpper() == "UPPERRIGHT")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + ";2D_SetGripperPosition /position:UpperLeft;" + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + ";2D_SetGripperPosition /position:UpperCenter;" + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + ";2D_SetGripperPosition /position:CenterLeft;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_Center + ";2D_SetGripperPosition /position:Center;" + _sHandlePosition_Prefix + _sHandlePosition_Center + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + ";2D_SetGripperPosition /position:CenterRight;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + ";2D_SetGripperPosition /position:LowerLeft;" + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + ";2D_SetGripperPosition /position:LowerCenter;" + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerRight + ";2D_SetGripperPosition /position:LowerRight;" + _sHandlePosition_Prefix + _sHandlePosition_LowerRight
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_UpperRight));
                    }
                    else if (_ActualHandlePostion.ToUpper() == "CENTERLEFT")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + ";2D_SetGripperPosition /position:UpperLeft;" + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + ";2D_SetGripperPosition /position:UpperCenter;" + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + ";2D_SetGripperPosition /position:UpperRight;" + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + "|"                            
                            + _sHandlePosition_Prefix + _sHandlePosition_Center + ";2D_SetGripperPosition /position:Center;" + _sHandlePosition_Prefix + _sHandlePosition_Center + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + ";2D_SetGripperPosition /position:CenterRight;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + ";2D_SetGripperPosition /position:LowerLeft;" + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + ";2D_SetGripperPosition /position:LowerCenter;" + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerRight + ";2D_SetGripperPosition /position:LowerRight;" + _sHandlePosition_Prefix + _sHandlePosition_LowerRight
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_MiddleLeft));
                    }
                    else if (_ActualHandlePostion.ToUpper() == "CENTER")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + ";2D_SetGripperPosition /position:UpperLeft;" + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + ";2D_SetGripperPosition /position:UpperCenter;" + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + ";2D_SetGripperPosition /position:UpperRight;" + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + ";2D_SetGripperPosition /position:CenterLeft;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + ";2D_SetGripperPosition /position:CenterRight;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + ";2D_SetGripperPosition /position:LowerLeft;" + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + ";2D_SetGripperPosition /position:LowerCenter;" + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerRight + ";2D_SetGripperPosition /position:LowerRight;" + _sHandlePosition_Prefix + _sHandlePosition_LowerRight
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_MiddleCenter));
                    }
                    else if (_ActualHandlePostion.ToUpper() == "CENTERRIGHT")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + ";2D_SetGripperPosition /position:UpperLeft;" + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + ";2D_SetGripperPosition /position:UpperCenter;" + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + ";2D_SetGripperPosition /position:UpperRight;" + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + ";2D_SetGripperPosition /position:CenterLeft;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_Center + ";2D_SetGripperPosition /position:Center;" + _sHandlePosition_Prefix + _sHandlePosition_Center + "|"                            
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + ";2D_SetGripperPosition /position:LowerLeft;" + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + ";2D_SetGripperPosition /position:LowerCenter;" + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerRight + ";2D_SetGripperPosition /position:LowerRight;" + _sHandlePosition_Prefix + _sHandlePosition_LowerRight
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_MiddleRight));
                    }
                    else if (_ActualHandlePostion.ToUpper() == "LOWERLEFT")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + ";2D_SetGripperPosition /position:UpperLeft;" + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + ";2D_SetGripperPosition /position:UpperCenter;" + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + ";2D_SetGripperPosition /position:UpperRight;" + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + ";2D_SetGripperPosition /position:CenterLeft;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_Center + ";2D_SetGripperPosition /position:Center;" + _sHandlePosition_Prefix + _sHandlePosition_Center + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + ";2D_SetGripperPosition /position:CenterRight;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + "|"                            
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + ";2D_SetGripperPosition /position:LowerCenter;" + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerRight + ";2D_SetGripperPosition /position:LowerRight;" + _sHandlePosition_Prefix + _sHandlePosition_LowerRight
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_LowerLeft));
                    }
                    else if (_ActualHandlePostion.ToUpper() == "LOWERCENTER")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + ";2D_SetGripperPosition /position:UpperLeft;" + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + ";2D_SetGripperPosition /position:UpperCenter;" + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + ";2D_SetGripperPosition /position:UpperRight;" + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + ";2D_SetGripperPosition /position:CenterLeft;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_Center + ";2D_SetGripperPosition /position:Center;" + _sHandlePosition_Prefix + _sHandlePosition_Center + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + ";2D_SetGripperPosition /position:CenterRight;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + ";2D_SetGripperPosition /position:LowerLeft;" + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + "|"                            
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerRight + ";2D_SetGripperPosition /position:LowerRight;" + _sHandlePosition_Prefix + _sHandlePosition_LowerRight
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_LowerCenter));
                    }
                    else if (_ActualHandlePostion.ToUpper() == "LOWERRIGHT")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + ";2D_SetGripperPosition /position:UpperLeft;" + _sHandlePosition_Prefix + _sHandlePosition_UpperLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + ";2D_SetGripperPosition /position:UpperCenter;" + _sHandlePosition_Prefix + _sHandlePosition_UpperCenter + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + ";2D_SetGripperPosition /position:UpperRight;" + _sHandlePosition_Prefix + _sHandlePosition_UpperRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + ";2D_SetGripperPosition /position:CenterLeft;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_Center + ";2D_SetGripperPosition /position:Center;" + _sHandlePosition_Prefix + _sHandlePosition_Center + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + ";2D_SetGripperPosition /position:CenterRight;" + _sHandlePosition_Prefix + _sHandlePosition_MiddleRight + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + ";2D_SetGripperPosition /position:LowerLeft;" + _sHandlePosition_Prefix + _sHandlePosition_LowerLeft + "|"
                            + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter + ";2D_SetGripperPosition /position:LowerCenter;" + _sHandlePosition_Prefix + _sHandlePosition_LowerCenter
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_MP_LowerRight));
                    }                    
                    #endregion

                    #region Macro gripper
                    if (oSettings.GetBoolSetting("USER.PanelLayoutGui.Settings.GripperFromMacro", 0))
                    {
                        _commandGroup1.AddCommand(string.Empty, "2D_ToggleGripperFromMacro", ribbonBar.AddIcon(_SVGIcon_MP_GripperFromMacro_Yes));                     
                    }
                    else
                    {
                        _commandGroup1.AddCommand(string.Empty, "2D_ToggleGripperFromMacro", ribbonBar.AddIcon(_SVGIcon_MP_GripperFromMacro_No));
                    }
                    #endregion

                    #region data overtaking

                    #region provide language depending text(s)
                    #region ApplyDataPrefix
                    MultiLangString mlsApplyData = new MultiLangString();
                    mlsApplyData.AddString(ISOCode.Language.L_de_DE, "Übernahme: ");
                    mlsApplyData.AddString(ISOCode.Language.L_en_US, "Apply: ");
                    string _sApplyData_Prefix = mlsApplyData.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sApplyData_Prefix))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sApplyData_Prefix = mlsApplyData.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region DimensionsFromPartsMasterData
                    MultiLangString mlsApplyFrom_PartsMasterData = new MultiLangString();
                    mlsApplyFrom_PartsMasterData.AddString(ISOCode.Language.L_de_DE, "Abmessung aus Artikelstamm");
                    mlsApplyFrom_PartsMasterData.AddString(ISOCode.Language.L_en_US, "Dimensions from parts master data");
                    string _sApplyFrom_PartsMasterData = mlsApplyFrom_PartsMasterData.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sApplyFrom_PartsMasterData))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sApplyFrom_PartsMasterData = mlsApplyFrom_PartsMasterData.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region DimensionsFromMacroAndPartsMasterData
                    MultiLangString mlsApplyFrom_MacroAndPartsMasterData = new MultiLangString();
                    mlsApplyFrom_MacroAndPartsMasterData.AddString(ISOCode.Language.L_de_DE, "Makro und Abmessung aus Artikelstamm");
                    mlsApplyFrom_MacroAndPartsMasterData.AddString(ISOCode.Language.L_en_US, "Macros and dimensions from parts master data");
                    string _sApplyFrom_MacroAndPartsMasterData = mlsApplyFrom_MacroAndPartsMasterData.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sApplyFrom_MacroAndPartsMasterData))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sApplyFrom_MacroAndPartsMasterData = mlsApplyFrom_MacroAndPartsMasterData.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region DimensionsFromMacro
                    MultiLangString mlsApplyFrom_Macro = new MultiLangString();
                    mlsApplyFrom_Macro.AddString(ISOCode.Language.L_de_DE, "Makro aus Artikelstamm");
                    mlsApplyFrom_Macro.AddString(ISOCode.Language.L_en_US, "Macros from parts master data");
                    string _sApplyFrom_Macro = mlsApplyFrom_Macro.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sApplyFrom_Macro))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sApplyFrom_Macro = mlsApplyFrom_Macro.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region DimensionsManualInput
                    MultiLangString mlsApplyFrom_ManualInput = new MultiLangString();
                    mlsApplyFrom_ManualInput.AddString(ISOCode.Language.L_de_DE, "Manuelle Eingabe");
                    mlsApplyFrom_ManualInput.AddString(ISOCode.Language.L_en_US, "Manual input");
                    string _sApplyFrom_ManualInput = mlsApplyFrom_ManualInput.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sApplyFrom_ManualInput))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sApplyFrom_ManualInput = mlsApplyFrom_ManualInput.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion

                    #region DimensionsManualInputAndMacros
                    MultiLangString mlsApplyFrom_ManualInputAndMacro = new MultiLangString();
                    mlsApplyFrom_ManualInputAndMacro.AddString(ISOCode.Language.L_de_DE, "Manuelle Eingabe, Makro aus Artikelstamm");
                    mlsApplyFrom_ManualInputAndMacro.AddString(ISOCode.Language.L_en_US, "Manual input, macro from parts master data");
                    string _sApplyFrom_ManualInputAndMacro = mlsApplyFrom_ManualInputAndMacro.GetStringToDisplay(global_GuiLanguage);
                    if (String.IsNullOrEmpty(_sApplyFrom_ManualInputAndMacro))
                    {
                        //if actual GUI-language is not defined in multi-language-string, use en_US-text-version
                        _sApplyFrom_ManualInputAndMacro = mlsApplyFrom_ManualInputAndMacro.GetStringToDisplay(ISOCode.Language.L_en_US);
                    }
                    #endregion
                    #endregion


                    string _ActualDataApply = oSettings.GetStringSetting("USER.PanelLayoutGui.Settings.DataOvertaking", 0);
                    if (_ActualDataApply.ToUpper() == "SIZEFROMARTICLE")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sApplyFrom_MacroAndPartsMasterData + ";2D_SetDataOvertaking /data_from:MacroAndSizeFromArticle;" + _sApplyData_Prefix + _sApplyFrom_MacroAndPartsMasterData + "|"
                            + _sApplyFrom_Macro + ";2D_SetDataOvertaking /data_from:MacroFromArticle;" + _sApplyData_Prefix + _sApplyFrom_Macro + "|"
                            + _sApplyFrom_ManualInput + ";2D_SetDataOvertaking /data_from:ManualInput;" + _sApplyData_Prefix + _sApplyFrom_ManualInput + "|"
                            + _sApplyFrom_ManualInputAndMacro + ";2D_SetDataOvertaking /data_from:ManualInputMacroFromArticle;" + _sApplyData_Prefix + _sApplyFrom_ManualInputAndMacro
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_ApplyData_FromPart));
                    }
                    else if (_ActualDataApply.ToUpper() == "MACROANDSIZEFROMARTICLE")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sApplyFrom_PartsMasterData + ";2D_SetDataOvertaking /data_from:SizeFromArticle;" + _sApplyData_Prefix + _sApplyFrom_PartsMasterData + "|"
                            + _sApplyFrom_Macro + ";2D_SetDataOvertaking /data_from:MacroFromArticle;" + _sApplyData_Prefix + _sApplyFrom_Macro + "|"
                            + _sApplyFrom_ManualInput + ";2D_SetDataOvertaking /data_from:ManualInput;" + _sApplyData_Prefix + _sApplyFrom_ManualInput + "|"
                            + _sApplyFrom_ManualInputAndMacro + ";2D_SetDataOvertaking /data_from:ManualInputMacroFromArticle;" + _sApplyData_Prefix + _sApplyFrom_ManualInputAndMacro
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_ApplyData_FromPartAndMacro));
                    }
                    else if (_ActualDataApply.ToUpper() == "MACROFROMARTICLE")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sApplyFrom_PartsMasterData + ";2D_SetDataOvertaking /data_from:SizeFromArticle;" + _sApplyData_Prefix + _sApplyFrom_PartsMasterData + "|"
                            + _sApplyFrom_MacroAndPartsMasterData + ";2D_SetDataOvertaking /data_from:MacroAndSizeFromArticle;" + _sApplyData_Prefix + _sApplyFrom_MacroAndPartsMasterData + "|"                            
                            + _sApplyFrom_ManualInput + ";2D_SetDataOvertaking /data_from:ManualInput;" + _sApplyData_Prefix + _sApplyFrom_ManualInput + "|"
                            + _sApplyFrom_ManualInputAndMacro + ";2D_SetDataOvertaking /data_from:ManualInputMacroFromArticle;" + _sApplyData_Prefix + _sApplyFrom_ManualInputAndMacro
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_ApplyData_FromMacro));
                    }
                    else if (_ActualDataApply.ToUpper() == "MANUALINPUT")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sApplyFrom_PartsMasterData + ";2D_SetDataOvertaking /data_from:SizeFromArticle;" + _sApplyData_Prefix + _sApplyFrom_PartsMasterData + "|"
                            + _sApplyFrom_MacroAndPartsMasterData + ";2D_SetDataOvertaking /data_from:MacroAndSizeFromArticle;" + _sApplyData_Prefix + _sApplyFrom_MacroAndPartsMasterData + "|"
                            + _sApplyFrom_Macro + ";2D_SetDataOvertaking /data_from:MacroFromArticle;" + _sApplyData_Prefix + _sApplyFrom_Macro + "|"                            
                            + _sApplyFrom_ManualInputAndMacro + ";2D_SetDataOvertaking /data_from:ManualInputMacroFromArticle;" + _sApplyData_Prefix + _sApplyFrom_ManualInputAndMacro
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_ApplyData_ManualInput));
                    }
                    else if (_ActualDataApply.ToUpper() == "MANUALINPUTMACROFROMARTICLE")
                    {
                        string _commandCall = "2DMountingPanelHelper_PopUpMenu /Items:" + "\""
                            + _sApplyFrom_PartsMasterData + ";2D_SetDataOvertaking /data_from:SizeFromArticle;" + _sApplyData_Prefix + _sApplyFrom_PartsMasterData + "|"
                            + _sApplyFrom_MacroAndPartsMasterData + ";2D_SetDataOvertaking /data_from:MacroAndSizeFromArticle;" + _sApplyData_Prefix + _sApplyFrom_MacroAndPartsMasterData + "|"
                            + _sApplyFrom_Macro + ";2D_SetDataOvertaking /data_from:MacroFromArticle;" + _sApplyData_Prefix + _sApplyFrom_Macro + "|"
                            + _sApplyFrom_ManualInput + ";2D_SetDataOvertaking /data_from:ManualInput;" + _sApplyData_Prefix + _sApplyFrom_ManualInput                            
                            + "\"";
                        _commandGroup1.AddCommand(string.Empty, _commandCall, ribbonBar.AddIcon(_SVGIcon_ApplyData_ManualInputAndMacro));
                    }                    
                    #endregion
                }
            }            
        }

        public void RemoveRibbonMenu()
        {
            //ensure correct defined multi-languagestring for ribbon name
            this.InitializeRibbonText();

            var ownRibbonTab = new Eplan.EplApi.Gui.RibbonBar().GetTab(global_mls_RibbOwnTabName, true);
            if (ownRibbonTab != null)
            {
                #region remove 1st custom command group
                var _commandGroup1 = ownRibbonTab.GetCommandGroup(global_mls_CommandGroupName1, true);
                if (_commandGroup1 != null)
                {
                    if (_commandGroup1.IsCustom)
                    {
                        _commandGroup1.Remove();
                    }
                }               
                #endregion               
            }
        }

        public void InitializeRibbonText()
        {
            #region define possible MLS for RibbonTab-name / Command group names once
            //(required for clean creation / removal of own entries incl. correct multi-langauge handling)
            global_mls_RibbOwnTabName.AddString(ISOCode.Language.L_de_DE, "Betriebsmittel");
            global_mls_RibbOwnTabName.AddString(ISOCode.Language.L_en_US, "Devices");

            //1st command group                
            global_mls_CommandGroupName1.AddString(ISOCode.Language.L_de_DE, "2D-Schaltschrankaufbau: Utility");
            global_mls_CommandGroupName1.AddString(ISOCode.Language.L_en_US, "2D panel layout: Utility");          
            #endregion
        }

        public static string GetActiveEplanVersion()
        {
            string sEplanVersion = "0"; //default value = 0 to ensure, that EPLAN-version is correctly recognized 

            //try new varibale $(EPLAN_VERSION) first, if not valid, no possibility to get active get active EPLAN-version
            #region try to get active EPLAN-version
            if (PathMap.SubstitutePath("$(EPLAN_VERSION)") != "$(EPLAN_VERSION)")
            {
                sEplanVersion = PathMap.SubstitutePath("$(EPLAN_VERSION)");
            }
            else
            {
                //try different method to get version of executing eplan, in case the actual version doesn't support $(EPLAN_VERSION)
                string _sVersionCheck_FileName = Path.Combine(PathMap.SubstitutePath("$(BIN)"), "Eplan.EplApi.Baseu.dll");
                FileInfo oFI = new FileInfo(_sVersionCheck_FileName);
                if (oFI.Exists)
                {
                    var versionInfo = FileVersionInfo.GetVersionInfo(_sVersionCheck_FileName);
                    string _sProductVersion = versionInfo.ProductVersion;

                    //return main-version-infos (without buildno.)
                    if (_sProductVersion.Length >= 5)
                    {
                        sEplanVersion = _sProductVersion.Substring(0, 5);
                    }
                }
            }
            #endregion

            if (sEplanVersion == "0" || sEplanVersion == "$(EPLAN_VERSION)")
            {
                MultiLangString oMLSErrorText = new MultiLangString();
                oMLSErrorText.AddString(ISOCode.Language.L_en_US, "Unable to get actual EPLAN-version.");
                oMLSErrorText.AddString(ISOCode.Language.L_de_DE, "Die aktuelle EPLAN-Version konnte nicht ermittelt werden.");                
                CreateSysMessage(oMLSErrorText,MessageLevel.FatalError,ISOCode.Language.L_en_US);                                

                //ensure, sEplanVersion is numeric, to avoid Convert-errors
                sEplanVersion = "0";
            }
            return sEplanVersion;
        }

        public static void CreateSysMessage(MultiLangString mlsMessageText, MessageLevel messageLevel, ISOCode.Language languageFallback)
        {
            string _sGui_MessageText = mlsMessageText.GetStringToDisplay(global_GuiLanguage);
            if (String.IsNullOrEmpty(_sGui_MessageText))
            {
                //if actual GUI-language is not defined in multi-language-string, use fallback-language text-version
                _sGui_MessageText = mlsMessageText.GetStringToDisplay(languageFallback);
            }

            BaseException _Exception = new BaseException(_sGui_MessageText + " [Script: " + globalString_ScriptSolutionName + " (Version:" + globalString_ScriptVersionNo + ")]", messageLevel);
            _Exception.FixMessage();
        }       
       
    }
}